class Stage:
    NOT_STARTED = "not_started"
    PENDING = "pending"
    RUNNING = "running"
    PRUNED = "pruned"
    SUCCEEDED = "succeeded"
    FAILED = "failed"
    STOPPED = "stopped"
    STOPPING = "stopping"
