@import url(https://fonts.googleapis.com/css2?family=Roboto&family=Roboto+Mono&display=swap);@import url(https://fonts.googleapis.com/icon?family=Material+Icons);@font-face{font-display:"swap";font-family:UCity;font-weight:300;src:url(static/media/UCity-Light.8352e423a843d9a0c52a.otf) format("opentype")}@font-face{font-display:"swap";font-family:UCity;font-weight:400;src:url(static/media/UCity-Regular.e28f5006c1976d08baaa.otf) format("opentype")}@font-face{font-display:"swap";font-family:UCity;font-weight:600;src:url(static/media/UCity-Semibold.b37489cc447430fe4ba7.otf) format("opentype")}body{-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;font-family:Roboto,Oxygen,Ubuntu,Cantarell,Fira Sans,Droid Sans,Helvetica Neue,sans-serif;margin:0;overflow-y:overlay}code{font-family:source-code-pro,Menlo,Monaco,Consolas,Courier New,monospace}pre{font-size:.8em;max-height:40em;overflow:scroll}
/*# sourceMappingURL=main.2c16595e.css.map*/
